@@ -368,6 +368,16 @@ class util(object):
 				print ("ex:", e, rowid, snt)
 		print (f"[tobs] finished, {dbfile}, {name}")
 
+	def snt_kvr(self,dbfile, name=None, host='127.0.0.1', port=6666, db=0):  
+		''' clec.spacybs ->   hash : ( clec, idx, snt) , for dictGet, 2022.6.1  '''
+		import redis
+		r = redis.Redis(host=host, port=port, db=db, decode_responses=True)
+		if not name: name = dbfile.split('.')[0].lower()
+		r.delete(name)
+		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+			r.hset(name, rowid, snt ) 
+		print (f"[tokvr] finished, {dbfile}, {name}")
+
 	def idsource(self,dbfile, outfile=None ):  
 		''' clec.spacybs -> clec.idsource , 2022.2.11
 			{"_id": "140948871-9", "_source": {"rid": "10", "uid": "25110374", "sc": 14, "md5": "da891a7d81f7a5e43b571168cc483b6c dba0b4c99ef37cadfc4bacd61fcefa5b d6b199bfae35246564c598ac78d84c91 38a945eeff5b5a587a26dcc6560e0061 58605af6b50b01f15c0cc3ee2aa75e33 c30566c355ae09ea68673e2940d49d0a 7972c906aef51380310363093e141ef8 dabdd545400415da6d29125bf872"}}
@@ -462,12 +472,16 @@ class util(object):
 		print("toes finished:", dbfile, idxname)
 
 	def tosnt(self,dbfile):  
-		''' dump snt to console '''
-		for snt in Spacybs(dbfile).keys() :
-			print(snt)
+		''' dump snt to tsv, 2022.6.1 '''
+		for rowid, snt, bs in Spacybs(dbfile).items() : #for snt in Spacybs(dbfile).keys() :
+			print(f"{rowid}\t{snt}")
+			
+if __name__	== '__main__':
+	fire.Fire(util)
+
+'''
 
 	def merge(self, inpath, attachpath):
-		''' 2022.3.27 '''
 		conn = sqlite3.connect(inpath)
 		conn.text_factory = str
 		cur = conn.cursor()
@@ -475,11 +489,7 @@ class util(object):
 		cur.execute(f'insert or ignore into spacybs select * from w.spacybs')
 		conn.commit()
 		print ("finished:", inpath, attachpath) 
-			
-if __name__	== '__main__':
-	fire.Fire(util)
 
-'''
 def es_source(name, snt, doc, skip_punct:bool=True): 
 	id  = hashlib.md5(snt.strip().encode("utf-8")).hexdigest()
 	sntlen = len(doc)
