@@ -107,7 +107,7 @@ def verbnet(doc):
 	for name, ibeg, iend in matcher(doc):
 		arr = spacy.nlp.vocab[name].text.split(':') 
 		i = ibeg + int(arr[-1]) 
-		doc.user_data[f"verbnet-{i}"] = {"type":"verbnet", "start": ibeg, "end": iend, "lem":doc[i].lemma_, "lempos":doc[i].lemma_ + "_" + doc[i].pos_, "chunk":arr[0].strip()}
+		doc.user_data[f"verbnet-{i}"] = {"type":"verbnet", "start": ibeg, "end": iend, "lempos":doc[i].lemma_ + "_" + doc[i].pos_, "chunk":arr[0].strip()} #"lem":doc[i].lemma_,
 
 simple_sent		= lambda doc: len([t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT']) <= 0 
 complex_sent	= lambda doc: len([t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT']) > 0
@@ -122,13 +122,13 @@ def stype(doc):
 skeleton = lambda doc:  " ".join([ t.ent_type_ if t.ent_type_ else t.text if t.is_punct or t.dep_ == 'ROOT' else t.pos_ for t in doc ])
 def ske(doc): 
 	merge_clause(doc)
-	doc.user_data["ske"] = {"type":"ske","lem": ','.join([t.lemma_ for t in doc if t.dep_ == 'ROOT']),"chunk": skeleton(doc)}
+	doc.user_data["ske"] = {"type":"ske","lempos": ','.join([t.lemma_ + "_" + t.pos_ for t in doc if t.dep_ == 'ROOT']),"chunk": skeleton(doc)}
 
 def clause(doc):  # {'S.prep-0': {'type': 'S.prep', 'start': 0, 'end': 2, 'lem': 'consider', 'chunk': 'Considering the possibility'}, 'S.conj-9': {'type': 'S.conj', 'start': 9, 'end': 12, 'lem': 'be', 'chunk': 'she is ok .'}}
 	for v in [t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT' ] : # non-root
 		children = list(v.subtree) #end = children[-1].i 	tag = "S." + v.dep_   # S.advcl ,  S.conj 
 		start = children[0].i
-		doc.user_data[f"{type}-{start}"] = {"type":"cl", "tag": "S." + v.dep_,  "start": start, "end":children[-1].i + 1, "lem":v.lemma_,"lempos":v.lemma_ + "_" + v.pos_,"chunk": " ".join([c.text for c in v.subtree])}
+		doc.user_data[f"{type}-{start}"] = {"type":"cl", "kp": "S." + v.dep_,  "start": start, "end":children[-1].i + 1, "lempos":v.lemma_ + "_" + v.pos_,"chunk": " ".join([c.text for c in v.subtree])} #"lem":v.lemma_, NOT confuse with 'tok' 
 
 def attach(doc):
 	verbnet(doc)
